export function ensureCleanLocalGitStateFactory(dependencies) {
    const { gitCommandRunner, findRemoteAlias } = dependencies;
    async function ensureCleanLocalCopy() {
        const status = await gitCommandRunner.getShortStatus();
        if (status !== '') {
            throw new Error('Local copy is not clean');
        }
    }
    async function ensureMasterBranch() {
        const branchName = await gitCommandRunner.getCurrentBranchName();
        if (branchName !== 'master') {
            throw new Error('Not on master branch');
        }
    }
    async function ensureLocalIsEqualToRemote(remoteAlias) {
        const remoteBranch = `${remoteAlias}/master`;
        const commits = await gitCommandRunner.getSymmetricDifferencesBetweenBranches('master', remoteBranch);
        let commitsAhead = 0;
        let commitsBehind = 0;
        commits.forEach((commit) => {
            if (commit.startsWith('>')) {
                commitsBehind += 1;
            }
            else {
                commitsAhead += 1;
            }
        });
        if (commitsAhead > 0 || commitsBehind > 0) {
            const errorMessage = `Local git master branch is ${commitsAhead} commits ahead and ${commitsBehind} commits behind of ${remoteBranch}`;
            throw new Error(errorMessage);
        }
    }
    return async function ensureCleanLocalGitState(githubRepo) {
        await ensureCleanLocalCopy();
        await ensureMasterBranch();
        const remoteAlias = await findRemoteAlias(githubRepo);
        await gitCommandRunner.fetchRemote(remoteAlias);
        await ensureLocalIsEqualToRemote(remoteAlias);
    };
}
//# sourceMappingURL=ensure-clean-local-git-state.js.map